@@ -5,16 +5,12 @@ import xmltodict
 from openshift.dynamic.exceptions import ResourceNotFoundError
 from urllib3.exceptions import ProtocolError
 
-from ocp_resources.logger import get_logger
 from ocp_resources.node import Node
 from ocp_resources.pod import Pod
 from ocp_resources.resource import TIMEOUT, NamespacedResource
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
-LOGGER = get_logger(name=__name__)
-
-
 class VirtualMachine(NamespacedResource):
     """
     Virtual Machine object, inherited from Resource.
@@ -94,7 +90,7 @@ class VirtualMachine(NamespacedResource):
         Raises:
             TimeoutExpiredError: If timeout reached.
         """
-        LOGGER.info(
+        self.logger.info(
             f"Wait for {self.kind} {self.name} status to be {'ready' if status == True else status}"
         )
         samples = TimeoutSampler(
@@ -248,8 +244,8 @@ class VirtualMachineInstance(NamespacedResource):
 
             virt_pod = self.virt_launcher_pod
             if virt_pod:
-                LOGGER.debug(f"{virt_pod.name} *****LOGS*****")
-                LOGGER.debug(virt_pod.log(container="compute"))
+                self.logger.debug(f"{virt_pod.name} *****LOGS*****")
+                self.logger.debug(virt_pod.log(container="compute"))
 
             raise
 
@@ -265,7 +261,7 @@ class VirtualMachineInstance(NamespacedResource):
         Raises:
             TimeoutExpiredError: If resource not exists.
         """
-        LOGGER.info(
+        self.logger.info(
             f"Wait until {self.kind} {self.name} is "
             f"{'Paused' if pause else 'Unpuased'}"
         )
@@ -380,7 +376,7 @@ class VirtualMachineInstance(NamespacedResource):
     def os_version(self):
         vmi_os_version = self.instance.status.guestOSInfo.get("version", {})
         if not vmi_os_version:
-            LOGGER.warning(
+            self.logger.warning(
                 "Guest agent is not installed on the VM; OS version is not available."
             )
         return vmi_os_version
